<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van POLB_IN234000NL - Result Event Tracking</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/DTr1_XML.NL.sch"/>
    
    <include href="coreschematron/transmission-wrapper.NL.sch"/>
    <include href="coreschematron/controlAct-wrapper.NL.sch"/>

    <pattern is-a="transmission-wrapper" id="POLB_IN234000NL-wrapper">
        <param name="element" value="hl7:POLB_IN234000NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="POLB_IN234000NL-controlAct">
        <param name="element" value="hl7:POLB_IN234000NL/hl7:ControlActProcess"/>
    </pattern>

    <pattern id="Wrapper">
        <!-- profileId -->
        <rule context="hl7:profileId">
            <assert test="@root='2.16.840.1.113883.2.4.3.11.1' and(@extension='810')">In de
                transmission wrapper moet het element profileId worden gevuld met de waarde
                '810'</assert>
        </rule>
    </pattern>

    <pattern>
        <title>ControlActProcess</title>
        <rule context="hl7:ControlActProcess">
            <assert test="count(hl7:subject) = 1">ControlActProcess moet precies één subject
                bevatten.</assert>
        </rule>
    </pattern>

    <pattern>
        <title>ControlActProcess/ObservationEvent</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent">
            <assert test="hl7:id">ObservationEvent.id element ontbreekt</assert>
            <assert test="hl7:effectiveTime">ObservationEvent.effectiveTime element
                ontbreekt</assert>
            <assert test="not(hl7:derivationExpr)">ObservationEvent.derivationExpr niet
                gebruiken</assert>
            <assert test="hl7:text">ObservationEvent.text element ontbreekt</assert>
            <assert test="hl7:statusCode">ObservationEvent.statusCode element ontbreekt</assert>
            <assert test="hl7:effectiveTime">ObservationEvent.effectiveTime element
                ontbreekt</assert>
            <assert test="not(hl7:priorityCode)">ObservationEvent.priorityCode niet
                gebruiken</assert>
            <assert test="hl7:confidentialityCode">ObservationEvent.confidentialityCode element
                ontbreekt</assert>
            <assert test="not(hl7:reasonCode)">ObservationEvent.reasonCode niet gebruiken</assert>
            <assert test="not(hl7:value)">ObservationEvent.value niet gebruiken</assert>
            <assert test="not(hl7:interpretationCode)">ObservationEvent.interpretationCode niet
                gebruiken</assert>
            <assert test="not(hl7:methodCode)">ObservationEvent.methodCode niet gebruiken</assert>
            <assert test="not(hl7:specimen)">ObservationEvent.specimen niet gebruiken</assert>
            <assert test="not(hl7:device)">ObservationEvent.device niet gebruiken</assert>
            <assert test="not(hl7:consumable1)">ObservationEvent.consumable1 niet gebruiken</assert>
            <assert test="not(hl7:consumable2)">ObservationEvent.consumable2 niet gebruiken</assert>
            <assert test="hl7:recordTarget">ObservationEvent.recordTarget ontbreekt</assert>
            <assert test="not(hl7:performer)">ObservationEvent.performer niet gebruiken</assert>
            <assert test="hl7:author">ObservationEvent.author element ontbreekt</assert>
            <assert test="not(hl7:transcriber)">ObservationEvent.transcriber niet gebruiken</assert>
            <assert test="not(hl7:informationRecipient)">ObservationEvent.informationRecipient niet
                gebruiken</assert>
            <assert test="not(hl7:verifier)">ObservationEvent.verifier niet gebruiken</assert>
            <assert test="hl7:inFulfillmentOf">ObservationEvent.inFulfillmentOf element
                ontbreekt</assert>
            <assert test="not(hl7:definition)">ObservationEvent.definition niet gebruiken</assert>
            <assert test="not(hl7:reason)">ObservationEvent.reason niet gebruiken</assert>
            <assert test="not(hl7:derivedFrom1)">ObservationEvent.derivedFrom1 niet
                gebruiken</assert>
            <assert test="not(hl7:derivedFrom2)">ObservationEvent.derivedFrom2 niet
                gebruiken</assert>
            <assert test="not(hl7:referenceRange)">ObservationEvent.referenceRange niet
                gebruiken</assert>
            <assert test="not(hl7:pertinentInformation)">ObservationEvent.pertinentInformation niet
                gebruiken</assert>
            <assert test="not(hl7:component1)">ObservationEvent.component1 niet gebruiken</assert>
            <assert test="not(hl7:component2)">ObservationEvent.component2 niet gebruiken</assert>
            <assert test="not(hl7:subjectOf1)">ObservationEvent.subjectOf1 niet gebruiken</assert>
            <assert test="not(hl7:subjectOf2)">ObservationEvent.subjectOf2 niet gebruiken</assert>
            <assert test="not(hl7:componentOf)">ObservationEvent.componentOf niet gebruiken</assert>
        </rule>

        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent">
            <assert test="@classCode='OBS'">ObservationEvent@classCode is niet gelijk aan
                OBS</assert>
            <assert test="@moodCode='EVN'">ObservationEvent@moocCode is niet gelijk aan EVN</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/id</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:id">
            <assert test="@root and @extension">ObservationEvent.id is niet compleet</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/code</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:code">
            <assert test="@codeSystem='2.16.840.1.113883.6.1'">ObservationEvent.code/@codeSystem OID
                is niet gelijk aan LOINC 2.16.840.1.113883.6.1</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/text</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:text">
            <!-- text bevat het document in base 64 enc, omdat dit een content response is moet er altijd een document B64 aanwezig zijn -->
            <assert test="@mediaType='application/hl7-sda+xml'">ObservationEvent.text mediaType is
                niet gelijk aan application/hl7-sda+xml</assert>
            <assert test="@representation='B64'">ObservationEvent.text representation is niet gelijk
                aan B64 base 64</assert>
            <assert test="string-length(.)&gt;0">ObservationEvent.text bevat geen inhoud
                (document)</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/confidentialityCode</title>
        <rule
            context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:confidentialityCode">
            <assert test="@codeSystem='2.16.840.1.113883.5.25'">ObservationEvent.confidentialityCode
                codeSystem OID is niet gelijk '2.16.840.1.113883.5.25'</assert>
        </rule>
    </pattern>

    <pattern>
        <title>ControlActProcess/ObservationEvent/recordTarget</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:recordTarget">
            <assert test="hl7:patient and count(*)=1">De participatie recordTarget kan alleen het
                element patient bevatten</assert>
            <assert
                test="count(hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3' and @extension])>0"
                >BSN ontbreekt in Patient</assert>
            <assert test="count(hl7:patient/hl7:Person/hl7:name[@qualifier='BR'])=0"
                >RecordTarget/patient/person/name moet tenminste één element met qualifier=BR
                hebben.</assert>
            <assert test="hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"
                >RecordTarget/patient/id moet een burgerservicenummer zijn</assert>
        </rule>
    </pattern>

    <pattern>
        <title>ControlActProcess/ObservationEvent/author</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:author/hl7:time">
            <assert test="@value or @nullFlavor='UNK'">author/time ontbreekt of nullFlavor is niet
                gelijk aan 'UNK'</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/author/assignedEntity</title>
        <rule
            context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:author/hl7:assignedEntity">
            <assert test="not(hl7:assignedDevice)">assignedEntity.assignedDevice niet
                gebruiken</assert>
            <assert test="not(hl7:assignedOrganization)">assignedEntity.assignedOrganization niet
                gebruiken</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/author/assignedEntity/id</title>
        <rule
            context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:author/hl7:assignedEntity/hl7:id">
            <assert test="@root='2.16.528.1.1007.3.1'">assignedEntity.id/@root is niet
                '2.16.528.1.1007.3.1' (UZI-nummer personen)</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/author/assignedEntity/Organization/id</title>
        <rule
            context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:author/hl7:assignedEntity/hl7:Organization/hl7:id">
            <assert test="@root='2.16.528.1.1007.3.3'">assignedEntity.Organization.id/@root is niet
                '2.16.528.1.1007.3.3' (URA)</assert>
        </rule>
    </pattern>

    <pattern>
        <title>ControlActProcess/ObservationEvent/inFulfillmentOf</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:inFulfillmentOf">
            <assert test="hl7:placerOrder and not(hl7:fulfillerPromise)">inFulfillmentOf mag alleen
                naar de placerOrder verwijzen</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/inFulfillmentOf/placerOrder</title>
        <rule
            context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:inFulfillmentOf/hl7:placerOrder">
            <assert test="@moodCode='RQO'">inFulfillmentOf/placerOrder/@moodCode moet RQO
                zijn</assert>
        </rule>

        <title>ControlActProcess/ObservationEvent/inFulfillmentOf/placerOrder/id</title>
        <rule
            context="hl7:ControlActProcess/hl7:subject/hl7:observationEvent/hl7:inFulfillmentOf/hl7:placerOrder/hl7:id">
            <assert test="@root and @extension">inFulfillmentOf/placerOrder/id/@root of @extension
                ontbreekt</assert>
        </rule>
    </pattern>

</schema>
